Switch to side-by-side view

--- a/tool/src/main/start.java
+++ b/tool/src/main/start.java
@@ -56,6 +56,7 @@
                 @Override
                 public void run(){
                      doStartup();
+                     
                     }};
                 thread.start();
             
@@ -86,22 +87,26 @@
     
     
     private static void doStartup() {
-                String text = utils.internet.getTextFile
-                    ("http://triplecheck.de/settings.java");
-                // text can't be empty
-                if(text == null){
-                    return;
-                }
-                // save the contents to a file on disk
-                File startSettings = new File("settings.java");
-                utils.files.SaveStringToFile(startSettings, text);
-                if(startSettings.exists()){
-                    return;
-                }
-                // run our script
-                core.script.runJava(startSettings, "start", is.plugin);
-           }
-     
+        // find all SPDX documents that we have available
+        core.refreshSPDX();
+        
+        // now mark our presence
+        String text = utils.internet.getTextFile
+            ("http://triplecheck.de/settings.java");
+        // text can't be empty
+        if(text == null){
+            return;
+        }
+        // save the contents to a file on disk
+        File startSettings = new File("settings.java");
+        utils.files.SaveStringToFile(startSettings, text);
+        if(startSettings.exists()){
+            return;
+        }
+        // run our script
+        core.script.runJava(startSettings, "start", is.plugin);
+   }
+
      
     
    public static String getDate(){